==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/posted.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class KWL_MyPost {
	function my_story($Author,$AuthorEmail,$out) {
      global $TOPIC;
		$CONF = KWL_GetConf();

		$sql  = "SELECT * FROM T_Stories WHERE Author = '$Author' ";
		$sql .= "AND AuthorEmail = '$AuthorEmail' AND Verified = 'Y' ";
		$sql .= "ORDER BY Repostamp DESC LIMIT 5";
		$result = SqlQuery($sql);
		
		if (mysql_num_rows($result)) {
			$VAR['Content'] = $out->table_start("100%",'',0,0,3);

			while ($A = mysql_fetch_array($result)) {
				$topic = $TOPIC[$A['Topic']]['Topic'];
				$VAR['Content'] .= "<TR><TD ALIGN=LEFT>".
               "$CONF[dotchar]".
               "<A HREF=\"$CONF[G_URL]/stories.php?story=$A[Rid]\"><B>$A[Heading]</B></A>".
               "<FONT SIZE=\"-1\"> - (<A HREF=\"$CONF[G_URL]/stories.php?topic=$A[Topic]\">$topic</A>) ".
               _COMMENTS ."($A[replys]) - ". _POSTEDON . ": " . 
               KWL_DateFormat($A["Repostamp"]) ."</FONT></TD></TR>\n";
			}
         $VAR['Content'] .= $out->table_end();
         $VAR['Heading'] = $Author . _LAST5;
         KWL_DrawMain($VAR);
		}
	}

	function my_reply($Author,$AuthorEmail,$out) {
      $CONF = KWL_GetConf();

      $sql  = "SELECT * FROM T_Comments WHERE Author = '$Author' ";
      $sql .= "AND AuthorEmail = '$AuthorEmail' ";
      $sql .= "ORDER BY Birthstamp DESC LIMIT 5";
      $result = SqlQuery($sql);
      
      if (mysql_num_rows($result)) {
         $VAR['Content'] = $out->table_start("100%",'',0,0,3);
         while ($A = mysql_fetch_array($result)) {
            $title = "<b>". KWL_PrepareHtml(KWL_StringCut($A['Content'],50)) . "...</b>";
            $VAR['Content'] .= "<TR><TD ALIGN=LEFT>$CONF[dotchar]";
            if (SqlCount("T_Stories","Rid",$A['TopRid'])) {
               $VAR['Content'] .= "<A HREF=\"$CONF[G_URL]/comments.php?rid=$A[ParentRid]&story=$A[TopRid]#$A[Rid]\">$title</A>";
            } elseif (SqlCount("T_PollQuestions","Rid",$A['TopRid'])) {
               $VAR['Content'] .= "<A HREF=\"$CONF[G_URL]/pollbooth.php?poll=$A[TopRid]&aid=-1#$A[Rid]\">$title</A>";
            } else {
               $VAR['Content'] .= "<A HREF=\"$CONF[G_URL]/pages.php?page=$A[TopRid]#$A[Rid]\">$title</A>";
            }
            $VAR['Content'] .= " <FONT SIZE=\"-1\">". _COMMENTS ."(" .
                             $this->count_baby($A['Rid']) .") - ".
                             _POSTEDON . " " . KWL_DateFormat($A['Birthstamp']) .
                             "</FONT></TD></TR>\n";
         }
         $VAR['Content'] .= $out->table_end();
         $VAR['Heading'] = $Author . _LAST5C;
         KWL_DrawMain($VAR);
      }
   }

   function count_baby($rid,$num=0) {
      return SqlCount("T_Comments","ParentRid",$rid);
      /*
      $rt = SqlResult("SELECT count(*) FROM T_Comments WHERE ParentRid = '$rid' ORDER BY Birthstamp");
      if (mysql_num_rows($rt)) {
         ++$this->reply_num;
         while ($A = mysql_fetch_array($rt)) {
            $this->count_baby($A[Rid],$num+1);
         }
      }
      */
   }
}
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/include/posted.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class KWL_MyPost {
	function my_story($Author,$AuthorEmail,$out) {
      global $TOPIC;
		$CONF = KWL_GetConf();

		$sql  = "SELECT * FROM T_Stories WHERE Author = '$Author' ";
		$sql .= "AND AuthorEmail = '$AuthorEmail' AND Verified = 'Y' ";
		$sql .= "ORDER BY Repostamp DESC LIMIT 5";
		$result = SqlQuery($sql);
		
		if (mysql_num_rows($result)) {
			$VAR['Content'] = $out->table_start("100%",'',0,0,3);

			while ($A = mysql_fetch_array($result)) {
				$topic = $TOPIC[$A['Topic']]['Topic'];
				$VAR['Content'] .= "<tr><td align=\"left\">".
               "$CONF[dotchar]".
               "<a href=\"$CONF[G_URL]/stories.php?story=$A[Rid]\"><b>$A[Heading]</b></a>".
               " - (<a href=\"$CONF[G_URL]/stories.php?topic=$A[Topic]\">$topic</a>) ".
               _COMMENTS ."($A[replys]) - ". _POSTEDON . ": " . 
               KWL_DateFormat($A["Repostamp"]) ."</td></tr>\n";
			}
         $VAR['Content'] .= $out->table_end();
         $VAR['Heading'] = $Author . _LAST5;
         KWL_DrawMain($VAR);
		}
	}

	function my_reply($Author,$AuthorEmail,$out) {
      $CONF = KWL_GetConf();

      $sql  = "SELECT * FROM T_Comments WHERE Author = '$Author' ";
      $sql .= "AND AuthorEmail = '$AuthorEmail' ";
      $sql .= "ORDER BY Birthstamp DESC LIMIT 5";
      $result = SqlQuery($sql);
      
      if (mysql_num_rows($result)) {
         $VAR['Content'] = $out->table_start("100%",'',0,0,3);
         while ($A = mysql_fetch_array($result)) {
            $title = "<b>". KWL_PrepareHtml(KWL_StringCut($A['Content'],50)) . "...</b>";
            $VAR['Content'] .= "<tr><td align=\"left\">$CONF[dotchar]";
            if (SqlCount("T_Stories","Rid",$A['TopRid'])) {
               $VAR['Content'] .= "<a href=\"$CONF[G_URL]/comments.php?rid=$A[ParentRid]&amp;story=$A[TopRid]#$A[Rid]\">$title</a>";
            } elseif (SqlCount("T_PollQuestions","Rid",$A['TopRid'])) {
               $VAR['Content'] .= "<a href=\"$CONF[G_URL]/pollbooth.php?poll=$A[TopRid]&amp;aid=-1#$A[Rid]\">$title</a>";
            } else {
               $VAR['Content'] .= "<a href=\"$CONF[G_URL]/pages.php?page=$A[TopRid]#$A[Rid]\">$title</a>";
            }
            $VAR['Content'] .= " ". _COMMENTS ."(" .
                             $this->count_baby($A['Rid']) .") - ".
                             _POSTEDON . " " . KWL_DateFormat($A['Birthstamp']) .
                             "</td></tr>\n";
         }
         $VAR['Content'] .= $out->table_end();
         $VAR['Heading'] = $Author . _LAST5C;
         KWL_DrawMain($VAR);
      }
   }

   function count_baby($rid,$num=0) {
      return SqlCount("T_Comments","ParentRid",$rid);
      /*
      $rt = SqlResult("SELECT count(*) FROM T_Comments WHERE ParentRid = '$rid' ORDER BY Birthstamp");
      if (mysql_num_rows($rt)) {
         ++$this->reply_num;
         while ($A = mysql_fetch_array($rt)) {
            $this->count_baby($A[Rid],$num+1);
         }
      }
      */
   }
}
?>
